contexttools.get_time_signature_marks_attached_to_component
===========================================================

.. autofunction:: abjad.tools.contexttools.get_time_signature_marks_attached_to_component.get_time_signature_marks_attached_to_component
